# Looks for .png images in directory and copies them
# to given directory 
#
# Note: will overwrite existing files
#
import os
import shutil
import time
import sys
import getopt

# Instructions
help = 'collect_files.py -i <inputdirectory> -o <outputdirectory>'
   
# Look for .png files
ext = '.png'

def get_files_recursively(start_directory, filter_extension=None):
    
    for root, _, files in os.walk(start_directory):
        for file in files:
            if filter_extension is None or file.lower().endswith(filter_extension):
                yield os.path.join(root, file)
        
            
def selective_copy(source, target, file_extension=None):
    for file in get_files_recursively(source, file_extension):
        # Skip the already copied files if output is a subdir of input
        if os.path.dirname(file) != target:
            shutil.copy(file, target)
            print("The following file has been copied", file)

def confirm_or_exit():
     while True:
        confirm = input('Proceed? [y]Yes or [n]No: ')
        if confirm in ('y', 'n'):
            if confirm == 'n':
                print('> exit')
                exit()
            else: 
                return
        else:
            print("\n Invalid Option. Please Enter a Valid Option.")
    

def main(argv):

    # Read input and output directory from arguments
    inputDirectory = ''
    outputDirectory = ''
    try:
        opts, args = getopt.getopt(argv,"hi:o:",["ifile=","ofile="])
    except getopt.GetoptError:
        print(help)
        sys.exit(2)
    
    if len(argv) < 1:
        print(help)
        sys.exit()
        
    for opt, arg in opts:
        if opt == '-h':
            print(help)
            sys.exit()
        elif opt in ("-i", "--idir"):
            inputDirectory = arg
        elif opt in ("-o", "--odir"):
            outputDirectory = arg
            
    print('Input directory is ' + inputDirectory)
    print('Output directory is ' + outputDirectory)
    
    # Create output directory if not exists
    if not os.path.exists(outputDirectory):
        print('Create output directory ' + outputDirectory)
        os.makedirs(outputDirectory)
    
    print('Search and copy ' + ext + ' files from ' + inputDirectory + ' to ' + outputDirectory)
    confirm_or_exit()
    
    # Search and copy files
    selective_copy(inputDirectory,
                   outputDirectory,
                   ext)
            
    os.startfile(outputDirectory)
	
if __name__ == "__main__":
   main(sys.argv[1:])
	


